GlassfyAccountableSku class

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GlassfyAccountableSku(String? skuId, String? productId, GlassfyStore? store, bool? isInTrialPeriod, bool? isInIntroOfferPeriod, String? basePlanId, String? offerId)
GlassfyAccountableSku.fromJson(Map<String, dynamic> json)
factory

Properties

basePlanId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isInIntroOfferPeriod → bool?
final
isInTrialPeriod → bool?
final
offerId → String?
final
productId → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skuId → String?
finalinherited
store → GlassfyStore?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited