GlassfyPermission class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GlassfyPermission(String? permissionId, GlassfyEntitlement? entitlement, bool? isValid, DateTime? expireDate, List<GlassfyAccountableSku>? accountableSkus)
GlassfyPermission.fromJson(Map<String, dynamic> json)
factory

Properties

accountableSkus → List<GlassfyAccountableSku>?
final
entitlement → GlassfyEntitlement?
final
expireDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isValid → bool?
final
permissionId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited