GlassfyPermissions class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GlassfyPermissions(String? installationId, String? subscriberId, String? originalApplicationVersion, DateTime? originalApplicationDate, List<GlassfyPermission>? all)
GlassfyPermissions.fromJson(Map<String, dynamic> json)
factory

Properties

all ↔ List<GlassfyPermission>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installationId → String?
final
originalApplicationDate ↔ DateTime?
getter/setter pair
originalApplicationVersion → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriberId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited