GlassfyProduct class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GlassfyProduct(String? title, String? description, String? identifier, String? basePlanId, num? price, String? currencyCode, String? period, GlassfyProductDiscount? introductoryPrice, List<GlassfyProductDiscount>? discounts)
GlassfyProduct.fromJson(Map<String, dynamic> json)
factory

Properties

basePlanId → String?
final
currencyCode → String?
final
description → String?
final
discounts → List<GlassfyProductDiscount>?
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
final
introductoryPrice → GlassfyProductDiscount?
final
period → String?
final
price → num?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited