GlassfyProductDiscount class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GlassfyProductDiscount(num? price, String? period, int? numberOfPeriods, String? type)
GlassfyProductDiscount.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
numberOfPeriods → int?
final
period → String?
final
price → num?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited