GlassfyPurchaseHistory class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GlassfyPurchaseHistory(String? offeringId, String? productId, String? skuId, GlassfyEventType? type, GlassfyStore? store, DateTime? purchaseDate, DateTime? expireDate, String? transactionId, String? subscriberId, String? currencyCode, String? countryCode, bool? isInIntroOfferPeriod, String? promotionalOfferId, String? offerCodeRefName, String? licenseCode, String? webOrderLineItemId)
GlassfyPurchaseHistory.fromJson(Map<String, dynamic> json)
factory

Properties

countryCode → String?
final
currencyCode → String?
final
expireDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isInIntroOfferPeriod → bool?
final
licenseCode → String?
final
offerCodeRefName → String?
final
offeringId → String?
final
productId → String?
final
promotionalOfferId → String?
final
purchaseDate ↔ DateTime?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skuId → String?
final
store → GlassfyStore?
final
subscriberId → String?
final
transactionId → String?
final
type → GlassfyEventType?
final
webOrderLineItemId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited