GlassfySku class

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GlassfySku(String? skuId, String? productId, GlassfyStore? store, GlassfyElegibility? introductoryEligibility, GlassfyElegibility? promotionalEligibility, GlassfyProduct? product, Map<String, dynamic>? extravars, String? basePlanId, String? offerId, GlassfyProductDiscount? discount)
GlassfySku.fromJson(Map<String, dynamic> json)
factory

Properties

basePlanId → String?
final
discount → GlassfyProductDiscount?
final
extravars → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
introductoryEligibility → GlassfyElegibility?
final
offerId → String?
final
product → GlassfyProduct?
final
productId → String?
finalinherited
promotionalEligibility → GlassfyElegibility?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skuId → String?
finalinherited
store → GlassfyStore?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited