GlassfyStoreInfoPaddle class

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GlassfyStoreInfoPaddle(String? userid, String? planId, String? subscriptionId, String? updateURL, String? cancelURL, Map<String, dynamic>? rawData)
GlassfyStoreInfoPaddle.fromJson(Map<String, dynamic> json)
factory

Properties

cancelURL → String?
final
hashCode → int
The hash code for this object.
no setterinherited
planId → String?
final
rawData → Map<String, dynamic>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → GlassfyStore?
finalinherited
subscriptionId → String?
final
updateURL → String?
final
userid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited